==> nextcloud-app-spreed-1%3A10.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/oc.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Invitat",
    "Open settings" : "Dobrir los paramètres",
    "Conversations" : "Discussions",
    "Andorra" : "Andòrra",
    "United Arab Emirates" : "Emirats Arabis Units",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angòla",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Amèrica, nord",
    "Austria" : "Austria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illas Åland",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegovina" : "Bòsnia e Ercegovina",
    "Barbados" : "Barbada",
    "Bangladesh" : "Bangladèsh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Barein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sant Bartomieu",
    "Bermuda" : "Bermudas",
    "Brunei Darussalam" : "Sultanat de Brunei",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Botan",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorusia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Cocos (Keeling) Islands" : "Illas Cocos (Keeling)",
    "Central African Republic" : "Centrafrica",
    "Congo" : "Congò",
    "Switzerland" : "Soïssa",
    "Côte d'Ivoire" : "Còsta d'Evòri",
    "Cook Islands" : "Illas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameron",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Còsta Rica",
    "Cuba" : "Cubà",
    "Christmas Island" : "Illa Cristmas",
    "Cyprus" : "Chipre",
    "Germany" : "Alemanha",
    "Djibouti" : "Jiboti",
    "Denmark" : "Danemarc",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Republica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Eqüator",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "Western Sahara" : "Sahara occidental",
    "Eritrea" : "Eritrèa",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Illas Maldivas",
    "Micronesia, Federated States of" : "Micronesia, Estats Federats de",
    "Faroe Islands" : "Illas Feròe",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Reialme Unit de Grand Bretanha e d’Irlanda del Nòrd",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana francesa",
    "Guernsey" : "Alemanya",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinèa",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinèa Eqüatoriala",
    "Greece" : "Grèça",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e las illas Sandwich del Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinèa-Bissau",
    "Guyana" : "Guianà",
    "Hong Kong" : "Hong Kong",
    "Honduras" : "Hondures",
    "Croatia" : "Croacia",
    "Haiti" : "Aïtí",
    "Hungary" : "Ongria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Territòris britanics de l'ocean indian",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaïca",
    "Jordan" : "Jordan",
    "Japan" : "Japon",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirghizstan",
    "Cambodia" : "Cambòtja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comòras",
    "Saint Kitts and Nevis" : "Sant Kitts e Nevis",
    "Korea, Democratic People's Republic of" : "Corèa, Republica Populara Democratica de",
    "Korea, Republic of" : "Corea",
    "Kuwait" : "Koweit",
    "Cayman Islands" : "Illas Caiman",
    "Kazakhstan" : "Cazacstan",
    "Lao People's Democratic Republic" : "Laòs",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "St. Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemborg",
    "Latvia" : "Letònia",
    "Libya" : "Libia",
    "Morocco" : "Marròc",
    "Monaco" : "Monegue",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illas Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Kanu",
    "Northern Mariana Islands" : "Illas Marianas del Nòrd",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurici",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "Mexic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nòva Caledònia",
    "Niger" : "Nigèr",
    "Norfolk Island" : "Norfòlk, Illa",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Holanda",
    "Norway" : "Norvègia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Novèla Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia francesa",
    "Papua New Guinea" : "Papoa-Nòva Guinèa",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistan",
    "Poland" : "Polonha",
    "Saint Pierre and Miquelon" : "Sant Pèire e Miquelon",
    "Pitcairn" : "Illas Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "La Reünion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federacion russa",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomon",
    "Seychelles" : "Seichèlas",
    "Sudan" : "Sodan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapor",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard e illa Jan Mayen",
    "Slovakia" : "Eslòvac",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "Sant Marin",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sodan del Sud",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Syrian Arab Republic" : "Siria",
    "Turks and Caicos Islands" : "Illas Turcas e Caïcas",
    "Chad" : "Chad",
    "French Southern Territories" : "Tèrras australas francesas",
    "Togo" : "Tògo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tatgiquistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tònga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat e Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Oganda",
    "United States Minor Outlying Islands" : "Illas menoras aluenhadas dels Estats Units d'America",
    "United States of America" : "Estats Units d'America",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Ozbequistan",
    "Saint Vincent and the Grenadines" : "Sant Vincenç e las Grenadinas",
    "Virgin Islands, U.S." : "Virgin Islands, U.S.",
    "Viet Nam" : "Vinyes",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemèn",
    "Mayotte" : "Maiòta",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Everyone" : "Tot lo monde",
    "Save changes" : "Salvar los cambiaments",
    "Saving …" : "Enregistrament…",
    "Saved!" : "Enregistrat",
    "None" : "Pas cap",
    "User" : "User",
    "Disabled" : "Desactivat",
    "Moderators" : "Moderators",
    "Users" : "Utilizaires",
    "Beta" : "Bèta",
    "Name" : "Nom",
    "Script" : "Escript",
    "Off" : "Atudat",
    "Language" : "Lenga",
    "Country" : "País",
    "Status" : "Estatut",
    "Created at" : "Creat lo",
    "Expires at" : "Expira lo",
    "Limits" : "Limits",
    "Pending" : "En espèra",
    "Error" : "Error",
    "Blocked" : "Blocat",
    "Active" : "Activa",
    "Expired" : "Expirat",
    "Saved" : "Enregistrat",
    "Copy link" : "Copiar lo ligam",
    "Dismiss" : "Regetar",
    "Enable video" : "Activar la vidèo",
    "Mute" : "Mut",
    "Favorite" : "Favorit",
    "Delete conversation" : "Suprimir la conversacion",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "No matches" : "Cap de resultat correspond pas",
    "Loading" : "Loading",
    "No search results" : "pas cap de resultats de recèrca",
    "Groups" : "Gropes",
    "Circles" : "Cercles",
    "Settings" : "Paramètres",
    "Password protect" : "Protegir per un senhal",
    "Back" : "Retorn",
    "Close" : "Tampar",
    "Microphone" : "Microfòn",
    "Camera" : "Aparelh de fotografiar",
    "Reply" : "Respondre",
    "Remove" : "Suprimir",
    "Today" : "Uèi",
    "Yesterday" : "Ièr",
    "Send message" : "Enviar un messatge",
    "Enabled" : "Activada",
    "Save" : "Salvar",
    "Channel name" : "Nom de la cadena",
    "Password" : "Senhal",
    "Login" : "Login",
    "Nickname" : "Escais",
    "Client ID" : "ID client",
    "Channel" : "Cadena",
    "running" : "en cors d'execucion",
    "guest" : "convidat",
    "No results" : "Pas cap de resultat",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Participants",
    "Chat" : "Messatjariá instantanèa (chat)",
    "Edit" : "Modificar",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Search" : "Search",
    "Toggle fullscreen" : "Bascular en mòde ecran complet",
    "Share link" : "Partejar lo ligam",
    "Password protection" : "Password protection",
    "Enter a password" : "Picatz un senhal",
    "Grid view" : "Vista en grasilha",
    "Send" : "Mandar",
    "Away" : "Absent",
    "Default" : "Defaut",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Android app" : "Aplicacion Android",
    "iOS app" : "Aplicacion iOS",
    "Contacts" : "Contactes",
    "Projects" : "Projèctes",
    "Password required" : "Senhal requerit",
    "Cancel" : "Anullar",
    "Submit" : "Transmetre"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-spreed-1%3A10.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/oc.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversacion",
    "(Duration %s)" : "(Durada %s)",
    "_%n guest_::_%n guests_" : ["%n convidat","%n convidats"],
    "_%n other_::_%n others_" : ["%n autre","%n autres"],
    "Talk" : "Talk",
    "Guest" : "Invitat",
    "New in Talk 6" : "Nòu dins Talk 6",
    "{actor} left the call" : "{actor} a quitat la sonada",
    "You left the call" : "Avètz quitat la sonada",
    "Open settings" : "Dobrir los paramètres",
    "Conversations" : "Discussions",
    "Andorra" : "Andòrra",
    "United Arab Emirates" : "Emirats Arabis Units",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua e Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angòla",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Amèrica, nord",
    "Austria" : "Austria",
    "Australia" : "Austràlia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Illas Åland",
    "Azerbaijan" : "Azerbaitjan",
    "Bosnia and Herzegovina" : "Bòsnia e Ercegovina",
    "Barbados" : "Barbada",
    "Bangladesh" : "Bangladèsh",
    "Belgium" : "Bèlgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Barein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sant Bartomieu",
    "Bermuda" : "Bermudas",
    "Brunei Darussalam" : "Sultanat de Brunei",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Botan",
    "Bouvet Island" : "Illa Bouvet",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorusia",
    "Belize" : "Belize",
    "Canada" : "Canadà",
    "Cocos (Keeling) Islands" : "Illas Cocos (Keeling)",
    "Central African Republic" : "Centrafrica",
    "Congo" : "Congò",
    "Switzerland" : "Soïssa",
    "Côte d'Ivoire" : "Còsta d'Evòri",
    "Cook Islands" : "Illas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameron",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Còsta Rica",
    "Cuba" : "Cubà",
    "Christmas Island" : "Illa Cristmas",
    "Cyprus" : "Chipre",
    "Germany" : "Alemanha",
    "Djibouti" : "Jiboti",
    "Denmark" : "Danemarc",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Republica Dominicana",
    "Algeria" : "Algeria",
    "Ecuador" : "Eqüator",
    "Estonia" : "Estònia",
    "Egypt" : "Egipte",
    "Western Sahara" : "Sahara occidental",
    "Eritrea" : "Eritrèa",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Illas Maldivas",
    "Micronesia, Federated States of" : "Micronesia, Estats Federats de",
    "Faroe Islands" : "Illas Feròe",
    "France" : "França",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Reialme Unit de Grand Bretanha e d’Irlanda del Nòrd",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guiana francesa",
    "Guernsey" : "Alemanya",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinèa",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Guinèa Eqüatoriala",
    "Greece" : "Grèça",
    "South Georgia and the South Sandwich Islands" : "Georgia del Sud e las illas Sandwich del Sud",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinèa-Bissau",
    "Guyana" : "Guianà",
    "Hong Kong" : "Hong Kong",
    "Honduras" : "Hondures",
    "Croatia" : "Croacia",
    "Haiti" : "Aïtí",
    "Hungary" : "Ongria",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Illa de Man",
    "India" : "Índia",
    "British Indian Ocean Territory" : "Territòris britanics de l'ocean indian",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Islàndia",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaïca",
    "Jordan" : "Jordan",
    "Japan" : "Japon",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirghizstan",
    "Cambodia" : "Cambòtja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comòras",
    "Saint Kitts and Nevis" : "Sant Kitts e Nevis",
    "Korea, Democratic People's Republic of" : "Corèa, Republica Populara Democratica de",
    "Korea, Republic of" : "Corea",
    "Kuwait" : "Koweit",
    "Cayman Islands" : "Illas Caiman",
    "Kazakhstan" : "Cazacstan",
    "Lao People's Democratic Republic" : "Laòs",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "St. Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libèria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituània",
    "Luxembourg" : "Luxemborg",
    "Latvia" : "Letònia",
    "Libya" : "Libia",
    "Morocco" : "Marròc",
    "Monaco" : "Monegue",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Illas Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Kanu",
    "Northern Mariana Islands" : "Illas Marianas del Nòrd",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritània",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurici",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "Mexic",
    "Malaysia" : "Malàisia",
    "Mozambique" : "Moçambic",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nòva Caledònia",
    "Niger" : "Nigèr",
    "Norfolk Island" : "Norfòlk, Illa",
    "Nigeria" : "Nigèria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Holanda",
    "Norway" : "Norvègia",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Novèla Zelanda",
    "Oman" : "Oman",
    "Panama" : "Panamà",
    "Peru" : "Peru",
    "French Polynesia" : "Polinesia francesa",
    "Papua New Guinea" : "Papoa-Nòva Guinèa",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistan",
    "Poland" : "Polonha",
    "Saint Pierre and Miquelon" : "Sant Pèire e Miquelon",
    "Pitcairn" : "Illas Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguai",
    "Qatar" : "Qatar",
    "Réunion" : "La Reünion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Federacion russa",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomon",
    "Seychelles" : "Seichèlas",
    "Sudan" : "Sodan",
    "Sweden" : "Suècia",
    "Singapore" : "Singapor",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard e illa Jan Mayen",
    "Slovakia" : "Eslòvac",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "Sant Marin",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sodan del Sud",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Syrian Arab Republic" : "Siria",
    "Turks and Caicos Islands" : "Illas Turcas e Caïcas",
    "Chad" : "Chad",
    "French Southern Territories" : "Tèrras australas francesas",
    "Togo" : "Tògo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tatgiquistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tònga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinitat e Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ucraïna",
    "Uganda" : "Oganda",
    "United States Minor Outlying Islands" : "Illas menoras aluenhadas dels Estats Units d'America",
    "United States of America" : "Estats Units d'America",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Ozbequistan",
    "Saint Vincent and the Grenadines" : "Sant Vincenç e las Grenadinas",
    "Virgin Islands, U.S." : "Virgin Islands, U.S.",
    "Viet Nam" : "Vinyes",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis e Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Iemèn",
    "Mayotte" : "Maiòta",
    "South Africa" : "Sudafrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Everyone" : "Tot lo monde",
    "Save changes" : "Salvar los cambiaments",
    "Saving …" : "Enregistrament…",
    "Saved!" : "Enregistrat",
    "None" : "Pas cap",
    "User" : "User",
    "Disabled" : "Desactivat",
    "Moderators" : "Moderators",
    "Users" : "Utilizaires",
    "Beta" : "Bèta",
    "Name" : "Nom",
    "Script" : "Escript",
    "Off" : "Atudat",
    "Language" : "Lenga",
    "Country" : "País",
    "Status" : "Estatut",
    "Created at" : "Creat lo",
    "Expires at" : "Expira lo",
    "Limits" : "Limits",
    "Pending" : "En espèra",
    "Error" : "Error",
    "Blocked" : "Blocat",
    "Active" : "Activa",
    "Expired" : "Expirat",
    "Saved" : "Enregistrat",
    "Copy link" : "Copiar lo ligam",
    "Dismiss" : "Regetar",
    "Enable video" : "Activar la vidèo",
    "Back" : "Retorn",
    "Mute" : "Mut",
    "Favorite" : "Favorit",
    "Password protection" : "Password protection",
    "Enter a password" : "Picatz un senhal",
    "Delete conversation" : "Suprimir la conversacion",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "No matches" : "Cap de resultat correspond pas",
    "Loading" : "Loading",
    "No search results" : "pas cap de resultats de recèrca",
    "Groups" : "Gropes",
    "Circles" : "Cercles",
    "Settings" : "Paramètres",
    "Password protect" : "Protegir per un senhal",
    "Close" : "Tampar",
    "Microphone" : "Microfòn",
    "Camera" : "Aparelh de fotografiar",
    "Reply" : "Respondre",
    "Remove" : "Suprimir",
    "Today" : "Uèi",
    "Yesterday" : "Ièr",
    "Send message" : "Enviar un messatge",
    "Enabled" : "Activada",
    "Save" : "Salvar",
    "Channel name" : "Nom de la cadena",
    "Password" : "Senhal",
    "Login" : "Login",
    "Nickname" : "Escais",
    "Client ID" : "ID client",
    "Channel" : "Cadena",
    "running" : "en cors d'execucion",
    "guest" : "convidat",
    "No results" : "Pas cap de resultat",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Participants",
    "Chat" : "Messatjariá instantanèa (chat)",
    "Edit" : "Modificar",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Search" : "Search",
    "Toggle fullscreen" : "Bascular en mòde ecran complet",
    "Grid view" : "Vista en grasilha",
    "Send" : "Mandar",
    "Away" : "Absent",
    "Default" : "Defaut",
    "The password is wrong. Try again." : "Lo senhal es incorrècte. Ensajatz tornamai.",
    "Android app" : "Aplicacion Android",
    "iOS app" : "Aplicacion iOS",
    "Contacts" : "Contactes",
    "Share link" : "Partejar lo ligam",
    "Projects" : "Projèctes",
    "Password required" : "Senhal requerit",
    "Cancel" : "Anullar",
    "Submit" : "Transmetre"
},
"nplurals=2; plural=(n > 1);");
